==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebDropdownGroupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownGroupDescription } from "./WebDropdownGroupDescription";
/**
 * @hidden
 */
export let WebDropdownGroupDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownGroupDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownGroupDescriptionMetadata.a == null) {
                WebDropdownGroupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownGroupDescriptionMetadata.c(WebDropdownGroupDescriptionMetadata.a);
            }
            if (a.j(WebDropdownGroupDescriptionMetadata.a)) {
                return;
            }
            a.y(WebDropdownGroupDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownGroup");
            a.item("__tagNameWC", "String:igc-dropdown-group");
        }
        static d(a) {
            WebDropdownGroupDescriptionMetadata.b(a);
            a.aa("WebDropdownGroup", () => new WebDropdownGroupDescription());
            a.z("WebDropdownGroup", WebDropdownGroupDescriptionMetadata.a);
        }
    }
    WebDropdownGroupDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownGroupDescriptionMetadata, 'WebDropdownGroupDescriptionMetadata');
    WebDropdownGroupDescriptionMetadata.a = null;
    return WebDropdownGroupDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebDropdownGroupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownGroupDescription } from "./WebDropdownGroupDescription";
/**
 * @hidden
 */
export let WebDropdownGroupDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownGroupDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownGroupDescriptionMetadata.a == null) {
                WebDropdownGroupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownGroupDescriptionMetadata.c(WebDropdownGroupDescriptionMetadata.a);
            }
            if (a.k(WebDropdownGroupDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDropdownGroupDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownGroup");
            a.item("__tagNameWC", "String:igc-dropdown-group");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebDropdownGroupDescriptionMetadata.b(a);
            a.ac("WebDropdownGroup", () => new WebDropdownGroupDescription());
            a.ab("WebDropdownGroup", WebDropdownGroupDescriptionMetadata.a);
        }
    }
    WebDropdownGroupDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownGroupDescriptionMetadata, 'WebDropdownGroupDescriptionMetadata');
    WebDropdownGroupDescriptionMetadata.a = null;
    return WebDropdownGroupDescriptionMetadata;
})();
